@@ -4,6 +4,7 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 05.05.2015: Changed parameter 'ignoreCase' to 'ignore.case' for 'checkSubset' function.
 # 11.10.2014: Added 'focus', added 'parent' parameter.
 # 28.06.2014: Added help button and moved save gui checkbox.
 # 08.05.2014: Implemented 'checkDataset'.
@@ -12,11 +13,10 @@
 # 12.01.2014: Replaced 'subset' with native code.
 # 08.12.2013: First version.
 
-#' @title Calculate Precision
+#' @title Table Precision
 #'
 #' @description
-#' \code{tablePrecision_gui} is a GUI wrapper for the \code{\link{tablePrecision}}
-#'  function.
+#' GUI wrapper for the \code{\link{tablePrecision}} function.
 #'
 #' @details
 #' Simplifies the use of the \code{\link{tablePrecision}} function by providing 
@@ -291,7 +291,7 @@ tablePrecision_gui <- function(env=parent.frame(), savegui=NULL,
       chksubset_txt <- checkSubset(data=val_data,
                                    ref=val_ref,
                                    console=FALSE,
-                                   ignoreCase=val_ignore,
+                                   ignore.case=val_ignore,
                                    word=val_word)
       
       gtext (text = chksubset_txt, width = NULL, height = 300, font.attr = NULL, 
